@@ -3,7 +3,7 @@
  * Copyright (C) 2007, 2008 Alp Toker <alp@atoker.com>
  * Copyright (C) 2008 Collabora Ltd.
  * Copyright (C) 2011, 2017 Igalia S.L.
- * Portions Copyright (c) 2011 Motorola Mobility, Inc.  All rights reserved.
+ * Portions Copyright (c) 2011 Motorola Mobility, Inc. All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -38,7 +38,6 @@
 #include <wpe/WebKitFormSubmissionRequest.h>
 #include <wpe/WebKitHitTestResult.h>
 #include <wpe/WebKitInputMethodContext.h>
-#include <wpe/WebKitJavascriptResult.h>
 #include <wpe/WebKitNavigationAction.h>
 #include <wpe/WebKitNotification.h>
 #include <wpe/WebKitOptionMenu.h>
@@ -56,6 +55,7 @@
 #include <wpe/WebKitWebsitePolicies.h>
 #include <wpe/WebKitWindowProperties.h>
 
+#include <wpe/WebKitNetworkSession.h>
 
 #include <wpe/WebKitColor.h>
 #include <wpe/WebKitRectangle.h>
@@ -64,11 +64,6 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_TYPE_WEB_VIEW            (webkit_web_view_get_type())
-#define WEBKIT_WEB_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), WEBKIT_TYPE_WEB_VIEW, WebKitWebView))
-#define WEBKIT_IS_WEB_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
-#define WEBKIT_IS_WEB_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  WEBKIT_TYPE_WEB_VIEW))
-#define WEBKIT_WEB_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  WEBKIT_TYPE_WEB_VIEW, WebKitWebViewClass))
 
 WEBKIT_DECLARE_DERIVABLE_TYPE (WebKitWebView, webkit_web_view, WEBKIT, WEB_VIEW, GObject)
 
@@ -153,8 +148,11 @@ typedef enum {
  * detected by trying to display any kind of resource (e.g. an image)
  * from an untrusted source.
  *
- * Enum values used to denote the different events which can trigger
- * the detection of insecure content.
+ * Enum values previously used to denote the different events which can trigger
+ * the detection of insecure content. Since 2.46, WebKit generally no longer
+ * loads insecure content in secure contexts.
+ *
+ * Deprecated: 2.46
  */
 typedef enum {
     WEBKIT_INSECURE_CONTENT_RUN,
@@ -264,7 +262,6 @@ struct _WebKitWebViewClass {
 
     gboolean   (* context_menu)                (WebKitWebView               *web_view,
                                                 WebKitContextMenu           *context_menu,
-                                                void                        *event,
                                                 WebKitHitTestResult         *hit_test_result);
 
     void       (* context_menu_dismissed)      (WebKitWebView               *web_view);
@@ -296,41 +293,50 @@ struct _WebKitWebViewClass {
     gboolean   (* query_permission_state)      (WebKitWebView               *web_view,
                                                 WebKitPermissionStateQuery  *query);
 
-    /*< private >*/
-    void (*_webkit_reserved0) (void);
-    void (*_webkit_reserved1) (void);
-    void (*_webkit_reserved2) (void);
-    void (*_webkit_reserved3) (void);
-    void (*_webkit_reserved4) (void);
 
+    /*< private >*/
+    void (*_webkit_reserved0)  (void);
+    void (*_webkit_reserved1)  (void);
+    void (*_webkit_reserved2)  (void);
+    void (*_webkit_reserved3)  (void);
+    void (*_webkit_reserved4)  (void);
+    void (*_webkit_reserved5)  (void);
+    void (*_webkit_reserved6)  (void);
+    void (*_webkit_reserved7)  (void);
+    void (*_webkit_reserved8)  (void);
+    void (*_webkit_reserved9)  (void);
+    void (*_webkit_reserved10) (void);
+    void (*_webkit_reserved11) (void);
+    void (*_webkit_reserved12) (void);
+    void (*_webkit_reserved13) (void);
+    void (*_webkit_reserved14) (void);
+    void (*_webkit_reserved15) (void);
+    void (*_webkit_reserved16) (void);
+    void (*_webkit_reserved17) (void);
+    void (*_webkit_reserved18) (void);
+    void (*_webkit_reserved19) (void);
+    void (*_webkit_reserved20) (void);
+    void (*_webkit_reserved21) (void);
+    void (*_webkit_reserved22) (void);
+    void (*_webkit_reserved23) (void);
+    void (*_webkit_reserved24) (void);
+    void (*_webkit_reserved25) (void);
+    void (*_webkit_reserved26) (void);
+    void (*_webkit_reserved27) (void);
+    void (*_webkit_reserved28) (void);
+    void (*_webkit_reserved29) (void);
+    void (*_webkit_reserved30) (void);
 };
 
 
 WEBKIT_API WebKitWebView *
 webkit_web_view_new                                  (WebKitWebViewBackend      *backend);
 
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_related_view                (WebKitWebViewBackend      *backend,
-                                                      WebKitWebView             *web_view);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_context                     (WebKitWebViewBackend      *backend,
-                                                      WebKitWebContext          *context);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_settings                    (WebKitWebViewBackend      *backend,
-                                                      WebKitSettings            *settings);
-
-WEBKIT_API WebKitWebView *
-webkit_web_view_new_with_user_content_manager        (WebKitWebViewBackend      *backend,
-                                                      WebKitUserContentManager  *user_content_manager);
 
 WEBKIT_API WebKitWebViewBackend *
 webkit_web_view_get_backend                          (WebKitWebView             *web_view);
 
 
-WEBKIT_API gboolean
-webkit_web_view_is_ephemeral                         (WebKitWebView             *web_view);
 
 WEBKIT_API gboolean
 webkit_web_view_is_controlled_by_automation          (WebKitWebView             *web_view);
@@ -338,8 +344,8 @@ webkit_web_view_is_controlled_by_automation          (WebKitWebView
 WEBKIT_API WebKitAutomationBrowsingContextPresentation
 webkit_web_view_get_automation_presentation_type     (WebKitWebView             *web_view);
 
-WEBKIT_API WebKitWebsiteDataManager *
-webkit_web_view_get_website_data_manager             (WebKitWebView             *web_view);
+WEBKIT_API WebKitNetworkSession *
+webkit_web_view_get_network_session                  (WebKitWebView             *web_view);
 
 WEBKIT_API WebKitWebContext *
 webkit_web_view_get_context                          (WebKitWebView             *web_view);
@@ -507,49 +513,6 @@ webkit_web_view_call_async_javascript_function_finish(WebKitWebView
                                                       GAsyncResult              *result,
                                                       GError                   **error);
 
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript                       (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_finish                (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript_in_world              (WebKitWebView             *web_view,
-                                                      const gchar               *script,
-                                                      const gchar               *world_name,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_in_world_finish       (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_call_async_javascript_function) void
-webkit_web_view_run_async_javascript_function_in_world (WebKitWebView           *web_view,
-                                                        const gchar             *body,
-                                                        GVariant                *arguments,
-                                                        const char              *world_name,
-                                                        GCancellable            *cancellable,
-                                                        GAsyncReadyCallback      callback,
-                                                        gpointer                 user_data);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript) void
-webkit_web_view_run_javascript_from_gresource        (WebKitWebView             *web_view,
-                                                      const gchar               *resource,
-                                                      GCancellable              *cancellable,
-                                                      GAsyncReadyCallback        callback,
-                                                      gpointer                   user_data);
-
-WEBKIT_DEPRECATED_FOR(webkit_web_view_evaluate_javascript_finish) WebKitJavascriptResult *
-webkit_web_view_run_javascript_from_gresource_finish (WebKitWebView             *web_view,
-                                                      GAsyncResult              *result,
-                                                      GError                   **error);
 
 WEBKIT_API WebKitWebResource *
 webkit_web_view_get_main_resource                    (WebKitWebView             *web_view);
@@ -691,6 +654,11 @@ webkit_web_view_get_web_extension_mode               (WebKitWebView
 WEBKIT_API const gchar*
 webkit_web_view_get_default_content_security_policy  (WebKitWebView             *web_view);
 
+WEBKIT_API gboolean
+webkit_web_view_get_theme_color                      (WebKitWebView             *web_view,
+                                                      WebKitColor               *color);
+
+
 /**
  * webkit_web_view_run_async_javascript_function_in_world:
  * @web_view: a #WebKitWebView
